@@ -45,7 +45,7 @@ extern LWLockId shmem_lockid;
 #define TDAYS (1000*24*3600)
 
 static void unregister_event(int event_id, int sid);
-static char*find_and_remove_message_item(int message_id, int sid,
+static char* find_and_remove_message_item(int message_id, int sid,
 							 bool all, bool remove_all,
 							 bool filter_message,
 							 int *sleep, char **event_name);
@@ -248,7 +248,7 @@ find_event(text *event_name, bool create, int *event_id)
 
 		ereport(ERROR,
 				(errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
-				 errmsg("event registeration error"),
+				 errmsg("event registration error"),
 				 errdetail("Too many registered events."),
 				 errhint("There are too many collaborating sessions. Increase MAX_EVENTS in 'pipe.h'.")));
 	}
