@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.5.  */
+/* A Bison parser, made by GNU Bison 3.7.4.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -31,8 +31,9 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-/* Undocumented macros, especially those whose name start with YY_,
-   are private implementation details.  Do not rely on them.  */
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
 
 #ifndef YY_ORAFCE_SQL_YY_SQLPARSE_H_INCLUDED
 # define YY_ORAFCE_SQL_YY_SQLPARSE_H_INCLUDED
@@ -44,22 +45,27 @@
 extern int orafce_sql_yydebug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
   enum yytokentype
   {
-    X_IDENT = 258,
-    X_NCONST = 259,
-    X_SCONST = 260,
-    X_OP = 261,
-    X_PARAM = 262,
-    X_COMMENT = 263,
-    X_WHITESPACE = 264,
-    X_KEYWORD = 265,
-    X_OTHERS = 266,
-    X_TYPECAST = 267
+    YYEMPTY = -2,
+    YYEOF = 0,                     /* "end of file"  */
+    YYerror = 256,                 /* error  */
+    YYUNDEF = 257,                 /* "invalid token"  */
+    X_IDENT = 258,                 /* X_IDENT  */
+    X_NCONST = 259,                /* X_NCONST  */
+    X_SCONST = 260,                /* X_SCONST  */
+    X_OP = 261,                    /* X_OP  */
+    X_PARAM = 262,                 /* X_PARAM  */
+    X_COMMENT = 263,               /* X_COMMENT  */
+    X_WHITESPACE = 264,            /* X_WHITESPACE  */
+    X_KEYWORD = 265,               /* X_KEYWORD  */
+    X_OTHERS = 266,                /* X_OTHERS  */
+    X_TYPECAST = 267               /* X_TYPECAST  */
   };
+  typedef enum yytokentype yytoken_kind_t;
 #endif
 
 /* Value type.  */
@@ -80,7 +86,7 @@ union YYSTYPE
 		char *modificator;
 	}				val;
 
-#line 84 "sqlparse.h"
+#line 90 "sqlparse.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
